import getpass


class SettingVars(dict):
    def __init__(self, input_dict):
        super(SettingVars, self).__init__()
        self.log_name = input_dict.get('log_name', 'python app(%s)' % getpass.getuser())
        self.log_file = input_dict.get('log_file', '/tmp/simplesettings.log')
        self.verbosity = input_dict.get('log_verbosity', 4)
        self.update({
            "log_name": self.log_name,
            "log_file": self.log_file,
            "log_verbosity": self.verbosity,
        })
